Reactivated PI get emails
[myslice.git] / setup.py
index e902e32..d7008a3 100644 (file)
--- a/setup.py
+++ b/setup.py
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
# Setup script for myslice
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>
 # INRIA (c) 2013
@@ -13,12 +13,15 @@ from distutils.core import setup
 packages= [ os.path.dirname(init) for init in (glob("*/__init__.py")+glob("*/*/__init__.py")) ]
 
 setup(packages = packages,
+      # xxx somehow this does not seem to show up in debian packaging
       scripts = [ 'apache/unfold-init-ssl.sh' ],
       data_files = [ 
-        ( 'static/js', glob ('static/js/*')),
-        ( 'static/css', glob ('static/css/*')),
-        ( 'static/img', glob ('static/img/*')),
-        ( 'static/fonts', glob ('static/fonts/*')),
-        ( 'templates', glob ('templates/*')),
-        ( 'apache', [ 'apache/myslice.conf' ]),
+          ( '/usr/share/unfold/static/js', glob ('static/js/*')),
+          ( '/usr/share/unfold/static/css', glob ('static/css/*')),
+          ( '/usr/share/unfold/static/img', glob ('static/img/*')),
+          ( '/usr/share/unfold/static/fonts', glob ('static/fonts/*')),
+          ( '/usr/share/unfold/templates', glob ('templates/*')),
+          ( 'apache', [ 'apache/unfold.conf', 'apache/unfold-ssl.conf', 'apache/unfold.wsgi' ]),
+          ( '/etc/unfold/trusted_roots', []),
+          ( '/var/unfold', []),
         ])
@@ -1,6 +1,6 @@
 #!/usr/bin/python
 #
-# Setup script for myslice
+# Setup script for myslice+unfold
 #
 # Thierry Parmentelat <thierry.parmentelat@inria.fr>